==> pgbackrest_1.28.orig.tar.gz: pgbackrest-release-1.28/test/src/test.c <==
/***********************************************************************************************************************************
C Test Wrapper

This wrapper runs the the C unit tests.
***********************************************************************************************************************************/
#include <assert.h>
#include <stdio.h>
#include <string.h>

#include "common/harnessTest.h"

/***********************************************************************************************************************************
C files to be tested

The files are included directly so the test can see and manipulate variables and functions in the module without the need to extern.
If a .c file does not exist for a module then the header file will be included instead.
***********************************************************************************************************************************/
{[C_INCLUDE]}

/***********************************************************************************************************************************
The test code is included directly so it can freely interact with the included C files
***********************************************************************************************************************************/
{[C_TEST_INCLUDE]}

/***********************************************************************************************************************************
main - run the tests
***********************************************************************************************************************************/
int
main(void)
{
    // Initialize tests
    //      run, selected
    {[C_TEST_LIST]}

    // Run the tests
    testRun();

    // End test run an make sure all tests ran
    testComplete();

    printf("\nTESTS COMPLETED SUCCESSFULLY (DESPITE ANY ERROR MESSAGES YOU SAW)\n");
    fflush(stdout);
}

==> pgbackrest_2.00.orig.tar.gz: pgbackrest-release-2.00/test/src/test.c <==
/***********************************************************************************************************************************
C Test Wrapper

This wrapper runs the the C unit tests.
***********************************************************************************************************************************/
#include <assert.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/stat.h>

#ifndef NO_ERROR
    #include "common/error.h"
#endif

#include "common/harnessTest.h"

#ifndef NO_LOG
    #include "common/logTest.h"
#endif

#ifndef NO_MEM_CONTEXT
    #include "common/memContext.h"
#endif

/***********************************************************************************************************************************
C files to be tested

The files are included directly so the test can see and manipulate variables and functions in the module without the need to extern.
If a .c file does not exist for a module then the header file will be included instead.
***********************************************************************************************************************************/
{[C_INCLUDE]}

/***********************************************************************************************************************************
The test code is included directly so it can freely interact with the included C files
***********************************************************************************************************************************/
{[C_TEST_INCLUDE]}

/***********************************************************************************************************************************
main - run the tests
***********************************************************************************************************************************/
int
main(void)
{
    // Set neutral umask for testing
    umask(0000);

    // Set globals
    testPathSet("{[C_TEST_PATH]}");

#ifndef NO_LOG
    // Initialize logging
    testLogInit();
#endif

    // Initialize tests
    //      run, selected
    {[C_TEST_LIST]}

#ifndef NO_ERROR
    TRY_BEGIN()
    {
#endif
        // Run the tests
        testRun();

#ifndef NO_LOG
        // Make sure there is nothing untested left in the log
        testLogFinal();
#endif

        // End test run and make sure all tests completed
        testComplete();

        printf("\nTESTS COMPLETED SUCCESSFULLY\n");
        fflush(stdout);
#ifndef NO_ERROR
    }
    CATCH_ANY()
    {
        fprintf(stderr, "TEST FAILED WITH %s, \"%s\" at %s:%d\n", errorName(), errorMessage(), errorFileName(), errorFileLine());
        fflush(stderr);
        exit(errorCode());
    }
#ifndef NO_MEM_CONTEXT
    FINALLY()
    {
        memContextFree(memContextTop());
    }
#endif
    TRY_END();
#endif
}
